----------------------------------------------------------------------
-- Configuration
----------------------------------------------------------------------

MerchantSafeConfig = { };
MerchantSafeConfig.Enabled = 1;
MerchantSafeConfig.AlertLevel = 2;
MerchantSafeConfig.PreventionLevel = 4;
MerchantSafeConfig.ColorCheck = 1;
MerchantSafeConfig.AltOverridePrev = 0;
MerchantSafeConfig.AltOverride = 0;

----------------------------------------------------------------------
-- Local Variables
----------------------------------------------------------------------

local MerchantSafe_AlreadyStarted;
local MerchantSafe_Item_Bag;
local MerchantSafe_Item_Slot;

-- Colors taken from DisenchantPredictor by Gazmik Fizzwidget
local MerchantSafe_Quality0 = "ff9d9d9d"; -- poor
local MerchantSafe_Quality1 = "ffffffff"; -- common
local MerchantSafe_Quality2 = "ff1eff00"; -- uncommon
local MerchantSafe_Quality3 = "ff0070dd"; -- rare
local MerchantSafe_Quality4 = "ffa335ee"; -- epic
local MerchantSafe_Quality5 = "ffff9d00"; -- legendary
local MerchantSafe_Quality6 = "ffffcc9d"; -- artifact

local MerchantSafe_OriginalContainerFrameItemButton_OnClick;
local MerchantSafe_ContainerFrameItemButton_OnClick;
local MerchantSafe_SellItem;

-- Create static popup
StaticPopupDialogs["MERCHANTSAFE"] = {
        text = TEXT(MERCHANTSAFE_SELL_ITEM),
        button1 = TEXT(ACCEPT),
        button2 = TEXT(CANCEL),
        OnAccept = function()
                MerchantSafe_SellItem();
        end,
        showAlert = 1,
        timeout = 0,
        exclusive = 1,
        whileDead = 1,
        interruptCinematic = 1
};

----------------------------------------------------------------------
-- OnFoo
----------------------------------------------------------------------

function MerchantSafe_OnLoad()

        -- Register Default Events
        this:RegisterEvent("VARIABLES_LOADED");
        this:RegisterEvent("PLAYER_ENTERING_WORLD");
        this:RegisterEvent("PLAYER_LEAVING_WORLD");

        if ( DEFAULT_CHAT_FRAME ) then
                MerchantSafe_ChatMessage(MERCHANTSAFE_ADDON.." "..MERCHANTSAFE_VERSION.." Loaded");
        end
end

function MerchantSafe_OnEvent(event, arg1)

        if ( event == "VARIABLES_LOADED" ) then

                -- Create Table For myAddOns
                MerchantSafeDetails = {
                        name = MERCHANTSAFE_ADDON,
                        description = MERCHANTSAFE_DESCRIPTION,
                        version = MERCHANTSAFE_VERSION,
                        releaseDate = MERCHANTSAFE_RELEASEDATE,
                        author = "Larry @ Baelgun [DE]",
                        email = "stonehedge@gmx.de",
                        category = MYADDONS_CATEGORY_INVENTORY,
                        frame = "MerchantSafe_OptFrame",
                        optionsframe = "MerchantSafe_OptFrame"
                };

                MerchantSafeHelp = {};
                MerchantSafeHelp[1] = MERCHANTSAFE_HELP1;
                MerchantSafeHelp[2] = MERCHANTSAFE_HELP2;

                -- Register Addon In myAddOns
                if (myAddOnsFrame_Register) then
                        myAddOnsFrame_Register(MerchantSafeDetails, MerchantSafeHelp);
                end
        end

        -- Register Ingame Events
        if (event == "PLAYER_ENTERING_WORLD") then
                this:RegisterEvent("MERCHANT_SHOW");
                this:RegisterEvent("MERCHANT_CLOSED");
        end

        -- Unregister Ingame Events
        if (event == "PLAYER_LEAVING_WORLD") then
                this:UnregisterEvent("MERCHANT_SHOW");
                this:UnregisterEvent("MERCHANT_CLOSED");
        end

        -- Hook Blizzard Functions
        if (event == "MERCHANT_SHOW") then
                MerchantSafe_OriginalContainerFrameItemButton_OnClick = ContainerFrameItemButton_OnClick;
                ContainerFrameItemButton_OnClick = MerchantSafe_PurchaseSlot;
        end

        -- Unhook Blizzard Functions
        if (event == "MERCHANT_CLOSED") then
                if (MerchantSafe_OriginalContainerFrameItemButton_OnClick) then
                        ContainerFrameItemButton_OnClick = MerchantSafe_OriginalContainerFrameItemButton_OnClick;
                        MerchantSafe_OriginalContainerFrameItemButton_OnClick = nil;
                end
        end

end

----------------------------------------------------------------------
-- Other functions
----------------------------------------------------------------------

--Function to give feedback in th chatwindow
function MerchantSafe_ChatMessage(message,r,g,b)

        --ChatMessage
        DEFAULT_CHAT_FRAME:AddMessage(MERCHANTSAFE_ADDON..": "..message,r,g,b);
end

--Code for getting the ItemData taken from SmartDisenchant by SkaDemon
function MerchantSafe_PurchaseSlot(buttonPress, ignoreShift)

        --StaticPopupDialog
        if ( (MerchantSafeConfig.Enabled == 1) and (buttonPress == "RightButton") ) then
                if ( MerchantFrame:IsVisible() ) then
                        local ItemLink = GetContainerItemLink(this:GetParent():GetID(),this:GetID());
                        local _,ItemCount,_,ItemQuality = GetContainerItemInfo(this:GetParent():GetID(),this:GetID());

                        if (ItemLink ~= nil) then

                            --Colorcode taken from DisenchantPredictor by Gazmik Fizzwidget
                            local _,_,ItemColor,_ = string.find(ItemLink, ".c(%x+).H(item:%d+:%d+:%d+:%d+).h%[.-%].h.r");

                            if (MerchantSafeConfig.ColorCheck == 1) then
                                    if (ItemColor == MerchantSafe_Quality0) then
                                       ItemQuality = 0;
                                    elseif (ItemColor == MerchantSafe_Quality1) then
                                       ItemQuality = 1;
                                    elseif (ItemColor == MerchantSafe_Quality2) then
                                       ItemQuality = 2;
                                    elseif (ItemColor == MerchantSafe_Quality3) then
                                       ItemQuality = 3;
                                    elseif (ItemColor == MerchantSafe_Quality4) then
                                       ItemQuality = 4;
                                    elseif (ItemColor == MerchantSafe_Quality5) then
                                       ItemQuality = 5;
                                    elseif (ItemColor == MerchantSafe_Quality6) then
                                       ItemQuality = 6;
                                    end
                            end

                            local ItemInfos = ItemLink;

                            if (
                               (MerchantSafeConfig.AltOverride ~= 1) and
                               (ItemQuality >= MerchantSafeConfig.AlertLevel)
                            ) then
                                    if (
                                       (MerchantSafeConfig.AltOverridePrev ~= 1) and
                                       (ItemQuality < MerchantSafeConfig.PreventionLevel)
                                    ) then
                                       MerchantSafe_ChatMessage(MERCHANTSAFE_ALERT.." "..ItemCount.."x "..ItemInfos);
                                       MerchantSafe_Item_Bag = this:GetParent():GetID();
                                       MerchantSafe_Item_Slot = this:GetID();
                                       StaticPopup_Show("MERCHANTSAFE");
                                    elseif (
                                       (MerchantSafeConfig.AltOverridePrev == 1) and
                                       IsAltKeyDown()
                                    ) then
                                       MerchantSafe_ChatMessage(MERCHANTSAFE_SOLD.." "..ItemCount.."x "..ItemInfos);
                                       MerchantSafe_OriginalContainerFrameItemButton_OnClick(buttonPress,ignoreShift);
                                     else
                                       MerchantSafe_ChatMessage(MERCHANTSAFE_PREVENT.." "..ItemCount.."x "..ItemInfos);
                                    end
                            elseif ( (MerchantSafeConfig.AltOverride == 1) and not IsAltKeyDown() ) then
                                    MerchantSafe_ChatMessage(MERCHANTSAFE_PREVENT.." "..ItemCount.."x "..ItemInfos);
                            else
                                    MerchantSafe_ChatMessage(MERCHANTSAFE_SOLD.." "..ItemCount.."x "..ItemInfos);
                                    MerchantSafe_OriginalContainerFrameItemButton_OnClick(buttonPress,ignoreShift);
                            end
                        else
                                MerchantSafe_OriginalContainerFrameItemButton_OnClick(buttonPress,ignoreShift);
                        end

                else
                        MerchantSafe_OriginalContainerFrameItemButton_OnClick(buttonPress,ignoreShift);
                end
        else
                MerchantSafe_OriginalContainerFrameItemButton_OnClick(buttonPress,ignoreShift);
        end
end

--Code taken from AutoProfit by Jason Allen
function MerchantSafe_SellItem()
         PickupContainerItem(MerchantSafe_Item_Bag, MerchantSafe_Item_Slot);
         MerchantItemButton_OnClick("LeftButton");
end