----------------------------------------------------------------------
-- Configuration
----------------------------------------------------------------------

MerchantSafeOptions = { };
MerchantSafeOptions.OptLocked = false;

----------------------------------------------------------------------
-- OnFoo
----------------------------------------------------------------------

function MerchantSafe_OptOnLoad()

        -- Register events
        this:RegisterEvent("VARIABLES_LOADED");

        UIPanelWindows['MerchantSafe_OptFrame'] = {area = 'center', pushable = 0};
        MerchantSafe_OptFrame:RegisterForDrag("LeftButton");
end

function MerchantSafe_OptOnEvent(event, arg1)

        -- Save Variables
        if (event == "VARIABLES_LOADED") then
                MerchantSafe_LoadSavOptions();
                MerchantSafe_UpdateLock();
        end
end

----------------------------------------------------------------------
-- Other functions
----------------------------------------------------------------------

-- Toggle options window
function MerchantSafe_Options()
        if (MerchantSafe_OptFrame:IsVisible()) then
                MerchantSafe_OptFrameCancelButton:Click();
        else
                ShowUIPanel(MerchantSafe_OptFrame);
        end
end

-- OnShow
function MerchantSafe_OptOnShow()
        PlaySound("igMainMenuOpen");
end

-- Toggle lock
function MerchantSafe_ToggleLock()
        if (MerchantSafeOptions.OptLocked) then
                MerchantSafeOptions.OptLocked = false;
                MerchantSafe_UpdateLock();
        else
                MerchantSafeOptions.OptLocked = true;
                MerchantSafe_UpdateLock();
        end
end

-- Change lock symbol. All gfx taken from Context Pet Buttons by Zuban
function MerchantSafe_UpdateLock()
        if (MerchantSafeOptions.OptLocked) then
                MerchantSafe_OptLockNorm:SetTexture("Interface\\AddOns\\MerchantSafe\\Images\\LockButton-Locked-Up");
                MerchantSafe_OptLockPush:SetTexture("Interface\\AddOns\\MerchantSafe\\Images\\LockButton-Locked-Down");
        else
                MerchantSafe_OptLockNorm:SetTexture("Interface\\AddOns\\MerchantSafe\\Images\\LockButton-Unlocked-Up");
                MerchantSafe_OptLockPush:SetTexture("Interface\\AddOns\\MerchantSafe\\Images\\LockButton-Unlocked-Down");
        end
end

-- Move options frame if allowed
function MerchantSafe_OptMoving()
        if (not MerchantSafeOptions.OptLocked) then
                MerchantSafe_OptFrame:StartMoving();
        end
end

-- Cancel options frame
function MerchantSafe_OptCancel()
        HideUIPanel(MerchantSafe_OptFrame);
        MerchantSafe_UndoOptions();
end

-- InitSlider. All slider functions taken from RangeSwitch by Zuban
function MerchantSafe_Options_InitSlider(slider, low, high)
        local lowText = getglobal(slider:GetName().."Low");
        local highText = getglobal(slider:GetName().."High");
        local text = getglobal(slider:GetName().."Text");

        lowText:SetText(low);
        highText:SetText(high);
        text:SetText(low);
        slider:SetMinMaxValues(low, high);
        slider:SetValueStep(1);
        slider:SetValue(low);
end

-- Get slider value
function MerchantSafe_Options_GetSliderValue(slider)
        return slider:GetValue();
end

-- Event SliderValueChanged
function MerchantSafe_Options_OnSliderValueChanged()
        local value = this:GetValue();
        MerchantSafe_Options_SetSliderValue(this, value);
end

-- Set slider value
function MerchantSafe_Options_SetSliderValue(slider, value)
        local text = getglobal(slider:GetName().."Text");
        local quality;

        if (value==0) then
                quality="|Cff9d9d9d"..MERCHANTSAFE_QUALITY0.."|r";
        elseif (value==1) then
                quality="|Cffffffff"..MERCHANTSAFE_QUALITY1.."|r";
        elseif (value==2) then
                quality="|Cff1eff00"..MERCHANTSAFE_QUALITY2.."|r";
        elseif (value==3) then
                quality="|Cff0070dd"..MERCHANTSAFE_QUALITY3.."|r";
        elseif (value==4) then
                quality="|Cffa335ee"..MERCHANTSAFE_QUALITY4.."|r";
        elseif (value==5) then
                quality="|Cffff9d00"..MERCHANTSAFE_QUALITY5.."|r";
        elseif (value==6) then
                quality="|Cffffcc9d"..MERCHANTSAFE_QUALITY6.."|r";
        end


        text:SetText(quality);
        slider:SetValue(value);
end

function MerchantSafe_OptCheckboxValueChanged(button)
        if (button == "OptAltOverPrev") then
                MerchantSafeConfig.AltOverridePrev = MerchantSafe_OptAltOverPrev:GetChecked();
                if (MerchantSafeConfig.AltOverPrev ~= nil) then
                        MerchantSafe_OptAltOverride:SetChecked();
                        MerchantSafe_ChatMessage(MERCHANTSAFE_OPTXXX);
                end
        elseif (button == "OptAltOverride") then
                MerchantSafeConfig.AltOverride = MerchantSafe_OptAltOverride:GetChecked();
                if (MerchantSafeConfig.AltOverride ~= nil) then
                        MerchantSafe_OptAltOverPrev:SetChecked();
                        MerchantSafe_ChatMessage(MERCHANTSAFE_OPTXXX);
                end
        end
end

-- Reset options
function MerchantSafe_UndoOptions()
        PlaySound("gsTitleOptionExit");
        MerchantSafe_LoadSavOptions();
        MerchantSafe_ChatMessage(MERCHANTSAFE_OPTCCL);
end

-- Load saved options
function MerchantSafe_LoadSavOptions()
        MerchantSafe_OptFrameEnable:SetChecked(MerchantSafeConfig.Enabled);
        MerchantSafe_Options_SetSliderValue(MerchantSafe_OptFrameAlert,MerchantSafeConfig.AlertLevel);
        MerchantSafe_Options_SetSliderValue(MerchantSafe_OptFramePrevent,MerchantSafeConfig.PreventionLevel);
        MerchantSafe_OptColorChk:SetChecked(MerchantSafeConfig.ColorCheck);
        MerchantSafe_OptAltOverPrev:SetChecked(MerchantSafeConfig.AltOverPrev);
        MerchantSafe_OptAltOverride:SetChecked(MerchantSafeConfig.AltOverride);
end

-- Save options
function MerchantSafe_OptSave()
        PlaySound("gsTitleOptionOK");
        HideUIPanel(MerchantSafe_OptFrame);
        MerchantSafeConfig.Enabled = MerchantSafe_OptFrameEnable:GetChecked();
        MerchantSafeConfig.AlertLevel = MerchantSafe_Options_GetSliderValue(MerchantSafe_OptFrameAlert);
        MerchantSafeConfig.PreventionLevel = MerchantSafe_Options_GetSliderValue(MerchantSafe_OptFramePrevent);
        MerchantSafeConfig.ColorCheck = MerchantSafe_OptColorChk:GetChecked();
        MerchantSafeConfig.AltOverPrev = MerchantSafe_OptAltOverPrev:GetChecked();
        MerchantSafeConfig.AltOverride = MerchantSafe_OptAltOverride:GetChecked();
        MerchantSafe_ChatMessage(MERCHANTSAFE_OPTSAV,0.50,0.50,1.00);
end